/*===========================================================================*/
/*   (BackEnd/c_main.scm)                                                    */
/*   Bigloo (4.6a)                                                           */
/*   Inria -- Sophia Antipolis (c)       Mon Jan 27 07:45:49 AM CET 2025     */
/*===========================================================================*/
/* COMPILATION: (/home/serrano/prgm/project/bigloo/4.6a/bin/bigloo -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /home/serrano/prgm/project/bigloo/4.6a/lib/bigloo/4.6a -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -stdc -indent BackEnd/c_main.scm) */
/* GC selection */
#define THE_GC BOEHM_GC

/* unsafe mode */
#define BIGLOO_UNSAFE 1

/* traces mode */
#define BIGLOO_TRACE 0

/* standard Bigloo include */
#include <bigloo.h>

#ifdef __cplusplus
extern "C"
{
#endif
#ifndef BGL_MODULE_TYPE_DEFINITIONS
#define BGL_MODULE_TYPE_DEFINITIONS
#ifndef BGL_BACKEND_C_MAIN_TYPE_DEFINITIONS
#define BGL_BACKEND_C_MAIN_TYPE_DEFINITIONS

/* object type definitions */
	typedef struct BgL_typez00_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_idz00;
		obj_t BgL_namez00;
		obj_t BgL_siza7eza7;
		obj_t BgL_classz00;
		obj_t BgL_coercezd2tozd2;
		obj_t BgL_parentsz00;
		bool_t BgL_initzf3zf3;
		bool_t BgL_magiczf3zf3;
		obj_t BgL_nullz00;
		obj_t BgL_z42z42;
		obj_t BgL_aliasz00;
		obj_t BgL_pointedzd2tozd2byz00;
		obj_t BgL_tvectorz00;
		obj_t BgL_locationz00;
		obj_t BgL_importzd2locationzd2;
		int BgL_occurrencez00;
	}              *BgL_typez00_bglt;

	typedef struct BgL_valuez00_bgl
	{
		header_t header;
		obj_t widening;
	}               *BgL_valuez00_bglt;

	typedef struct BgL_variablez00_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_idz00;
		obj_t BgL_namez00;
		struct BgL_typez00_bgl *BgL_typez00;
		struct BgL_valuez00_bgl *BgL_valuez00;
		obj_t BgL_accessz00;
		obj_t BgL_fastzd2alphazd2;
		obj_t BgL_removablez00;
		long BgL_occurrencez00;
		long BgL_occurrencewz00;
		bool_t BgL_userzf3zf3;
	}                  *BgL_variablez00_bglt;

	typedef struct BgL_globalz00_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_idz00;
		obj_t BgL_namez00;
		struct BgL_typez00_bgl *BgL_typez00;
		struct BgL_valuez00_bgl *BgL_valuez00;
		obj_t BgL_accessz00;
		obj_t BgL_fastzd2alphazd2;
		obj_t BgL_removablez00;
		long BgL_occurrencez00;
		long BgL_occurrencewz00;
		bool_t BgL_userzf3zf3;
		obj_t BgL_modulez00;
		obj_t BgL_importz00;
		bool_t BgL_evaluablezf3zf3;
		bool_t BgL_evalzf3zf3;
		obj_t BgL_libraryz00;
		obj_t BgL_pragmaz00;
		obj_t BgL_srcz00;
		obj_t BgL_qualifiedzd2typezd2namez00;
		obj_t BgL_initz00;
		obj_t BgL_aliasz00;
	}                *BgL_globalz00_bglt;

	typedef struct BgL_localz00_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_idz00;
		obj_t BgL_namez00;
		struct BgL_typez00_bgl *BgL_typez00;
		struct BgL_valuez00_bgl *BgL_valuez00;
		obj_t BgL_accessz00;
		obj_t BgL_fastzd2alphazd2;
		obj_t BgL_removablez00;
		long BgL_occurrencez00;
		long BgL_occurrencewz00;
		bool_t BgL_userzf3zf3;
		long BgL_keyz00;
		obj_t BgL_valzd2noescapezd2;
		bool_t BgL_volatilez00;
	}               *BgL_localz00_bglt;

	typedef struct BgL_nodez00_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_locz00;
		struct BgL_typez00_bgl *BgL_typez00;
	}              *BgL_nodez00_bglt;


#endif													// BGL_BACKEND_C_MAIN_TYPE_DEFINITIONS
#endif													// BGL_MODULE_TYPE_DEFINITIONS

	static obj_t BGl_requirezd2initializa7ationz75zzbackend_c_mainz00 = BUNSPEC;
	BGL_IMPORT obj_t BGl_za2classesza2z00zz__objectz00;
	extern obj_t BGl_lvtypezd2nodez12zc0zzast_lvtypez00(BgL_nodez00_bglt);
	static obj_t BGl_genericzd2initzd2zzbackend_c_mainz00(void);
	BGL_IMPORT obj_t BGl_stringzd2copyzd2zz__r4_strings_6_7z00(obj_t);
	static obj_t BGl_objectzd2initzd2zzbackend_c_mainz00(void);
	BGL_IMPORT obj_t BGl_za2inheritancesza2z00zz__objectz00;
	BGL_IMPORT obj_t BGl_readz00zz__readerz00(obj_t, obj_t);
	BGL_IMPORT obj_t BGl_openzd2inputzd2stringz12z12zz__r4_ports_6_10_1z00(obj_t,
		obj_t, obj_t);
	static obj_t BGl_methodzd2initzd2zzbackend_c_mainz00(void);
	extern obj_t BGl_za2pairza2z00zztype_cachez00;
	BGL_EXPORTED_DECL obj_t BGl_makezd2bigloozd2mainz00zzbackend_c_mainz00(void);
	extern obj_t BGl_za2moduleza2z00zzmodule_modulez00;
	BGL_EXPORTED_DECL obj_t
		BGl_modulezd2initializa7ationz75zzbackend_c_mainz00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzbackend_cplibz00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzbackend_c_prototypez00(long,
		char *);
	extern obj_t BGl_modulezd2initializa7ationz75zztools_shapez00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzast_lvtypez00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzast_glozd2defzd2(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzast_localz00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzast_sexpz00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzast_envz00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzast_nodez00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzast_varz00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzobject_slotsz00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzobject_classz00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zztype_cachez00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zztype_typez00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzmodule_modulez00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzengine_paramz00(long, char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__r4_ports_6_10_1z00(long,
		char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__r4_vectors_6_8z00(long,
		char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__r4_strings_6_7z00(long,
		char *);
	BGL_IMPORT obj_t
		BGl_modulezd2initializa7ationz75zz__r4_numbers_6_5_fixnumz00(long, char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__r4_symbols_6_4z00(long,
		char *);
	BGL_IMPORT obj_t
		BGl_modulezd2initializa7ationz75zz__r4_pairs_and_lists_6_3z00(long, char *);
	BGL_IMPORT obj_t
		BGl_modulezd2initializa7ationz75zz__r4_equivalence_6_2z00(long, char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__readerz00(long, char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__objectz00(long, char *);
	extern BgL_globalz00_bglt
		BGl_defzd2globalzd2sfunz12z12zzast_glozd2defzd2(obj_t, obj_t, obj_t, obj_t,
		obj_t, obj_t, obj_t, obj_t);
	static obj_t BGl_cnstzd2initzd2zzbackend_c_mainz00(void);
	static obj_t BGl_libraryzd2moduleszd2initz00zzbackend_c_mainz00(void);
	static obj_t BGl_z62makezd2bigloozd2mainz62zzbackend_c_mainz00(obj_t);
	extern BgL_localz00_bglt BGl_makezd2localzd2svarz00zzast_localz00(obj_t,
		BgL_typez00_bglt);
	static obj_t BGl_importedzd2moduleszd2initz00zzbackend_c_mainz00(void);
	static obj_t BGl_gczd2rootszd2initz00zzbackend_c_mainz00(void);
	extern BgL_nodez00_bglt BGl_sexpzd2ze3nodez31zzast_sexpz00(obj_t, obj_t,
		obj_t, obj_t);
	extern obj_t BGl_modulezd2initializa7ationzd2idza7zzmodule_modulez00(obj_t);
	extern obj_t BGl_globalz00zzast_varz00;
	extern obj_t BGl_za2mainza2z00zzmodule_modulez00;
	static obj_t __cnst[17];


	   
		 
		DEFINE_STRING(BGl_string1494z00zzbackend_c_mainz00,
		BgL_bgl_string1494za700za7za7b1507za7, "bigloo_main", 11);
	      DEFINE_STRING(BGl_string1495z00zzbackend_c_mainz00,
		BgL_bgl_string1495za700za7za7b1508za7, "backend_c_main", 14);
	      DEFINE_STRING(BGl_string1496z00zzbackend_c_mainz00,
		BgL_bgl_string1496za700za7za7b1509za7,
		"export now bigloo-main-procedure sfun (argv::obj) bigloo_main::obj value let z z::bint $long->bint begin %exit @ bigloo-initialized! __param argv ",
		146);
	     
		DEFINE_EXPORT_BGL_PROCEDURE
		(BGl_makezd2bigloozd2mainzd2envzd2zzbackend_c_mainz00,
		BgL_bgl_za762makeza7d2bigloo1510z00,
		BGl_z62makezd2bigloozd2mainz62zzbackend_c_mainz00, 0L, BUNSPEC, 0);

/* GC roots registration */
	static obj_t bgl_gc_roots_register()
	{
#if defined( BGL_GC_ROOTS )
#define ADD_ROOT( addr ) (addr > roots_max ? roots_max = addr : (addr < roots_min ? roots_min = addr : 0))
		void *roots_min = (void *) ULONG_MAX, *roots_max = 0;
		   
			 ADD_ROOT((void
				*) (&BGl_requirezd2initializa7ationz75zzbackend_c_mainz00));
#undef ADD_ROOT
		if   (roots_max > 0)
			     GC_add_roots(roots_min, ((void **) roots_max) + 1);
#endif
		     return BUNSPEC;
	}



/* module-initialization */
	BGL_EXPORTED_DEF obj_t
		BGl_modulezd2initializa7ationz75zzbackend_c_mainz00(long
		BgL_checksumz00_1950, char *BgL_fromz00_1951)
	{
		{
			if (CBOOL(BGl_requirezd2initializa7ationz75zzbackend_c_mainz00))
				{
					BGl_requirezd2initializa7ationz75zzbackend_c_mainz00 =
						BBOOL(((bool_t) 0));
					BGl_gczd2rootszd2initz00zzbackend_c_mainz00();
					BGl_libraryzd2moduleszd2initz00zzbackend_c_mainz00();
					BGl_cnstzd2initzd2zzbackend_c_mainz00();
					BGl_importedzd2moduleszd2initz00zzbackend_c_mainz00();
					return BGl_methodzd2initzd2zzbackend_c_mainz00();
				}
			else
				{
					return BUNSPEC;
				}
		}

	}



/* library-modules-init */
	obj_t BGl_libraryzd2moduleszd2initz00zzbackend_c_mainz00(void)
	{
		{	/* BackEnd/c_main.scm 15 */
			BGl_modulezd2initializa7ationz75zz__objectz00(0L, "backend_c_main");
			BGl_modulezd2initializa7ationz75zz__r4_strings_6_7z00(0L,
				"backend_c_main");
			BGl_modulezd2initializa7ationz75zz__readerz00(0L, "backend_c_main");
			BGl_modulezd2initializa7ationz75zz__r4_ports_6_10_1z00(0L,
				"backend_c_main");
			BGl_modulezd2initializa7ationz75zz__r4_symbols_6_4z00(0L,
				"backend_c_main");
			BGl_modulezd2initializa7ationz75zz__r4_equivalence_6_2z00(0L,
				"backend_c_main");
			BGl_modulezd2initializa7ationz75zz__r4_vectors_6_8z00(0L,
				"backend_c_main");
			BGl_modulezd2initializa7ationz75zz__r4_numbers_6_5_fixnumz00(0L,
				"backend_c_main");
			BGl_modulezd2initializa7ationz75zz__r4_pairs_and_lists_6_3z00(0L,
				"backend_c_main");
			return BUNSPEC;
		}

	}



/* cnst-init */
	obj_t BGl_cnstzd2initzd2zzbackend_c_mainz00(void)
	{
		{	/* BackEnd/c_main.scm 15 */
			{	/* BackEnd/c_main.scm 15 */
				obj_t BgL_cportz00_1939;

				{	/* BackEnd/c_main.scm 15 */
					obj_t BgL_stringz00_1946;

					BgL_stringz00_1946 = BGl_string1496z00zzbackend_c_mainz00;
					{	/* BackEnd/c_main.scm 15 */
						obj_t BgL_startz00_1947;

						BgL_startz00_1947 = BINT(0L);
						{	/* BackEnd/c_main.scm 15 */
							obj_t BgL_endz00_1948;

							BgL_endz00_1948 =
								BINT(STRING_LENGTH(((obj_t) BgL_stringz00_1946)));
							{	/* BackEnd/c_main.scm 15 */

								BgL_cportz00_1939 =
									BGl_openzd2inputzd2stringz12z12zz__r4_ports_6_10_1z00
									(BgL_stringz00_1946, BgL_startz00_1947, BgL_endz00_1948);
				}}}}
				{
					long BgL_iz00_1940;

					BgL_iz00_1940 = 16L;
				BgL_loopz00_1941:
					if ((BgL_iz00_1940 == (-1L)))
						{	/* BackEnd/c_main.scm 15 */
							return BUNSPEC;
						}
					else
						{	/* BackEnd/c_main.scm 15 */
							{	/* BackEnd/c_main.scm 15 */
								obj_t BgL_arg1506z00_1942;

								{	/* BackEnd/c_main.scm 15 */

									{	/* BackEnd/c_main.scm 15 */
										obj_t BgL_locationz00_1944;

										BgL_locationz00_1944 = BBOOL(((bool_t) 0));
										{	/* BackEnd/c_main.scm 15 */

											BgL_arg1506z00_1942 =
												BGl_readz00zz__readerz00(BgL_cportz00_1939,
												BgL_locationz00_1944);
										}
									}
								}
								{	/* BackEnd/c_main.scm 15 */
									int BgL_tmpz00_1978;

									BgL_tmpz00_1978 = (int) (BgL_iz00_1940);
									CNST_TABLE_SET(BgL_tmpz00_1978, BgL_arg1506z00_1942);
							}}
							{	/* BackEnd/c_main.scm 15 */
								int BgL_auxz00_1945;

								BgL_auxz00_1945 = (int) ((BgL_iz00_1940 - 1L));
								{
									long BgL_iz00_1983;

									BgL_iz00_1983 = (long) (BgL_auxz00_1945);
									BgL_iz00_1940 = BgL_iz00_1983;
									goto BgL_loopz00_1941;
								}
							}
						}
				}
			}
		}

	}



/* gc-roots-init */
	obj_t BGl_gczd2rootszd2initz00zzbackend_c_mainz00(void)
	{
		{	/* BackEnd/c_main.scm 15 */
			return bgl_gc_roots_register();
		}

	}



/* make-bigloo-main */
	BGL_EXPORTED_DEF obj_t BGl_makezd2bigloozd2mainz00zzbackend_c_mainz00(void)
	{
		{	/* BackEnd/c_main.scm 37 */
			{	/* BackEnd/c_main.scm 38 */
				obj_t BgL_argsz00_1624;

				{	/* BackEnd/c_main.scm 38 */
					BgL_localz00_bglt BgL_arg1309z00_1674;

					BgL_arg1309z00_1674 =
						BGl_makezd2localzd2svarz00zzast_localz00(
						((obj_t)
							CNST_TABLE_REF(0)),
						((BgL_typez00_bglt) BGl_za2pairza2z00zztype_cachez00));
					{	/* BackEnd/c_main.scm 38 */
						obj_t BgL_list1310z00_1675;

						BgL_list1310z00_1675 =
							MAKE_YOUNG_PAIR(((obj_t) BgL_arg1309z00_1674), BNIL);
						BgL_argsz00_1624 = BgL_list1310z00_1675;
				}}
				{	/* BackEnd/c_main.scm 38 */
					obj_t BgL_mainzd2bodyzd2_1625;

					{	/* BackEnd/c_main.scm 39 */
						bool_t BgL_test1513z00_1992;

						{	/* BackEnd/c_main.scm 39 */
							obj_t BgL_objz00_1860;

							BgL_objz00_1860 = BGl_za2mainza2z00zzmodule_modulez00;
							{	/* BackEnd/c_main.scm 39 */
								obj_t BgL_classz00_1861;

								BgL_classz00_1861 = BGl_globalz00zzast_varz00;
								if (BGL_OBJECTP(BgL_objz00_1860))
									{	/* BackEnd/c_main.scm 39 */
										BgL_objectz00_bglt BgL_arg1858z00_1863;

										BgL_arg1858z00_1863 =
											(BgL_objectz00_bglt) (BgL_objz00_1860);
										if (BGL_CONDEXPAND_ISA_ARCH64())
											{	/* BackEnd/c_main.scm 39 */
												long BgL_idxz00_1869;

												BgL_idxz00_1869 =
													BGL_OBJECT_INHERITANCE_NUM(BgL_arg1858z00_1863);
												BgL_test1513z00_1992 =
													(VECTOR_REF(BGl_za2inheritancesza2z00zz__objectz00,
														(BgL_idxz00_1869 + 2L)) == BgL_classz00_1861);
											}
										else
											{	/* BackEnd/c_main.scm 39 */
												bool_t BgL_res1492z00_1894;

												{	/* BackEnd/c_main.scm 39 */
													obj_t BgL_oclassz00_1877;

													{	/* BackEnd/c_main.scm 39 */
														obj_t BgL_arg1866z00_1885;
														long BgL_arg1867z00_1886;

														BgL_arg1866z00_1885 =
															(BGl_za2classesza2z00zz__objectz00);
														{	/* BackEnd/c_main.scm 39 */
															long BgL_arg1869z00_1887;

															BgL_arg1869z00_1887 =
																BGL_OBJECT_CLASS_NUM(BgL_arg1858z00_1863);
															BgL_arg1867z00_1886 =
																(BgL_arg1869z00_1887 - OBJECT_TYPE);
														}
														BgL_oclassz00_1877 =
															VECTOR_REF(BgL_arg1866z00_1885,
															BgL_arg1867z00_1886);
													}
													{	/* BackEnd/c_main.scm 39 */
														bool_t BgL__ortest_1115z00_1878;

														BgL__ortest_1115z00_1878 =
															(BgL_classz00_1861 == BgL_oclassz00_1877);
														if (BgL__ortest_1115z00_1878)
															{	/* BackEnd/c_main.scm 39 */
																BgL_res1492z00_1894 = BgL__ortest_1115z00_1878;
															}
														else
															{	/* BackEnd/c_main.scm 39 */
																long BgL_odepthz00_1879;

																{	/* BackEnd/c_main.scm 39 */
																	obj_t BgL_arg1855z00_1880;

																	BgL_arg1855z00_1880 = (BgL_oclassz00_1877);
																	BgL_odepthz00_1879 =
																		BGL_CLASS_DEPTH(BgL_arg1855z00_1880);
																}
																if ((2L < BgL_odepthz00_1879))
																	{	/* BackEnd/c_main.scm 39 */
																		obj_t BgL_arg1853z00_1882;

																		{	/* BackEnd/c_main.scm 39 */
																			obj_t BgL_arg1854z00_1883;

																			BgL_arg1854z00_1883 =
																				(BgL_oclassz00_1877);
																			BgL_arg1853z00_1882 =
																				BGL_CLASS_ANCESTORS_REF
																				(BgL_arg1854z00_1883, 2L);
																		}
																		BgL_res1492z00_1894 =
																			(BgL_arg1853z00_1882 ==
																			BgL_classz00_1861);
																	}
																else
																	{	/* BackEnd/c_main.scm 39 */
																		BgL_res1492z00_1894 = ((bool_t) 0);
																	}
															}
													}
												}
												BgL_test1513z00_1992 = BgL_res1492z00_1894;
											}
									}
								else
									{	/* BackEnd/c_main.scm 39 */
										BgL_test1513z00_1992 = ((bool_t) 0);
									}
							}
						}
						if (BgL_test1513z00_1992)
							{	/* BackEnd/c_main.scm 41 */
								obj_t BgL_arg1247z00_1630;

								{	/* BackEnd/c_main.scm 41 */
									obj_t BgL_arg1249z00_1631;
									obj_t BgL_arg1250z00_1632;

									{	/* BackEnd/c_main.scm 41 */
										obj_t BgL_arg1252z00_1633;
										obj_t BgL_arg1253z00_1634;

										BgL_arg1252z00_1633 =
											BGl_modulezd2initializa7ationzd2idza7zzmodule_modulez00
											(BGl_za2moduleza2z00zzmodule_modulez00);
										{	/* BackEnd/c_main.scm 43 */
											obj_t BgL_arg1254z00_1635;

											{	/* BackEnd/c_main.scm 43 */
												obj_t BgL_arg1255z00_1636;

												{	/* BackEnd/c_main.scm 43 */
													obj_t BgL_symbolz00_1895;

													BgL_symbolz00_1895 =
														BGl_za2moduleza2z00zzmodule_modulez00;
													{	/* BackEnd/c_main.scm 43 */
														obj_t BgL_arg1486z00_1896;

														BgL_arg1486z00_1896 =
															SYMBOL_TO_STRING(BgL_symbolz00_1895);
														BgL_arg1255z00_1636 =
															BGl_stringzd2copyzd2zz__r4_strings_6_7z00
															(BgL_arg1486z00_1896);
													}
												}
												BgL_arg1254z00_1635 =
													MAKE_YOUNG_PAIR(BgL_arg1255z00_1636, BNIL);
											}
											BgL_arg1253z00_1634 =
												MAKE_YOUNG_PAIR(BINT(0L), BgL_arg1254z00_1635);
										}
										BgL_arg1249z00_1631 =
											MAKE_YOUNG_PAIR(BgL_arg1252z00_1633, BgL_arg1253z00_1634);
									}
									{	/* BackEnd/c_main.scm 44 */
										obj_t BgL_arg1256z00_1637;
										obj_t BgL_arg1258z00_1638;

										{	/* BackEnd/c_main.scm 44 */
											obj_t BgL_arg1260z00_1639;

											{	/* BackEnd/c_main.scm 44 */
												obj_t BgL_arg1262z00_1640;

												{	/* BackEnd/c_main.scm 44 */
													obj_t BgL_arg1266z00_1641;

													BgL_arg1266z00_1641 =
														MAKE_YOUNG_PAIR(((obj_t) CNST_TABLE_REF(1)), BNIL);
													BgL_arg1262z00_1640 =
														MAKE_YOUNG_PAIR(
														((obj_t) CNST_TABLE_REF(2)), BgL_arg1266z00_1641);
												}
												BgL_arg1260z00_1639 =
													MAKE_YOUNG_PAIR(
													((obj_t) CNST_TABLE_REF(3)), BgL_arg1262z00_1640);
											}
											BgL_arg1256z00_1637 =
												MAKE_YOUNG_PAIR(BgL_arg1260z00_1639, BNIL);
										}
										{	/* BackEnd/c_main.scm 45 */
											obj_t BgL_arg1267z00_1642;

											{	/* BackEnd/c_main.scm 45 */
												obj_t BgL_arg1268z00_1643;

												{	/* BackEnd/c_main.scm 45 */
													obj_t BgL_arg1271z00_1644;

													{	/* BackEnd/c_main.scm 45 */
														obj_t BgL_arg1272z00_1645;
														obj_t BgL_arg1273z00_1646;

														{	/* BackEnd/c_main.scm 45 */
															obj_t BgL_arg1274z00_1647;

															{	/* BackEnd/c_main.scm 45 */
																obj_t BgL_arg1275z00_1648;
																obj_t BgL_arg1276z00_1649;

																{	/* BackEnd/c_main.scm 45 */
																	BgL_globalz00_bglt BgL_oz00_1897;

																	BgL_oz00_1897 =
																		((BgL_globalz00_bglt)
																		BGl_za2mainza2z00zzmodule_modulez00);
																	BgL_arg1275z00_1648 =
																		(((BgL_variablez00_bglt)
																			COBJECT(((BgL_variablez00_bglt)
																					BgL_oz00_1897)))->BgL_idz00);
																}
																{	/* BackEnd/c_main.scm 46 */
																	obj_t BgL_arg1277z00_1650;

																	{	/* BackEnd/c_main.scm 46 */
																		BgL_globalz00_bglt BgL_oz00_1898;

																		BgL_oz00_1898 =
																			((BgL_globalz00_bglt)
																			BGl_za2mainza2z00zzmodule_modulez00);
																		BgL_arg1277z00_1650 =
																			(((BgL_globalz00_bglt)
																				COBJECT(BgL_oz00_1898))->BgL_modulez00);
																	}
																	BgL_arg1276z00_1649 =
																		MAKE_YOUNG_PAIR(BgL_arg1277z00_1650, BNIL);
																}
																BgL_arg1274z00_1647 =
																	MAKE_YOUNG_PAIR(BgL_arg1275z00_1648,
																	BgL_arg1276z00_1649);
															}
															BgL_arg1272z00_1645 =
																MAKE_YOUNG_PAIR(
																((obj_t)
																	CNST_TABLE_REF(3)), BgL_arg1274z00_1647);
														}
														BgL_arg1273z00_1646 =
															MAKE_YOUNG_PAIR(
															((obj_t) CNST_TABLE_REF(0)), BNIL);
														BgL_arg1271z00_1644 =
															MAKE_YOUNG_PAIR(BgL_arg1272z00_1645,
															BgL_arg1273z00_1646);
													}
													BgL_arg1268z00_1643 =
														MAKE_YOUNG_PAIR(BgL_arg1271z00_1644, BNIL);
												}
												BgL_arg1267z00_1642 =
													MAKE_YOUNG_PAIR(
													((obj_t) CNST_TABLE_REF(4)), BgL_arg1268z00_1643);
											}
											BgL_arg1258z00_1638 =
												MAKE_YOUNG_PAIR(BgL_arg1267z00_1642, BNIL);
										}
										BgL_arg1250z00_1632 =
											MAKE_YOUNG_PAIR(BgL_arg1256z00_1637, BgL_arg1258z00_1638);
									}
									BgL_arg1247z00_1630 =
										MAKE_YOUNG_PAIR(BgL_arg1249z00_1631, BgL_arg1250z00_1632);
								}
								BgL_mainzd2bodyzd2_1625 =
									MAKE_YOUNG_PAIR(
									((obj_t) CNST_TABLE_REF(5)), BgL_arg1247z00_1630);
							}
						else
							{	/* BackEnd/c_main.scm 49 */
								obj_t BgL_arg1279z00_1651;

								{	/* BackEnd/c_main.scm 49 */
									obj_t BgL_arg1280z00_1652;
									obj_t BgL_arg1281z00_1653;

									{	/* BackEnd/c_main.scm 49 */
										obj_t BgL_arg1282z00_1654;
										obj_t BgL_arg1284z00_1655;

										BgL_arg1282z00_1654 =
											BGl_modulezd2initializa7ationzd2idza7zzmodule_modulez00
											(BGl_za2moduleza2z00zzmodule_modulez00);
										{	/* BackEnd/c_main.scm 51 */
											obj_t BgL_arg1285z00_1656;

											{	/* BackEnd/c_main.scm 51 */
												obj_t BgL_arg1287z00_1657;

												{	/* BackEnd/c_main.scm 51 */
													obj_t BgL_symbolz00_1899;

													BgL_symbolz00_1899 =
														BGl_za2moduleza2z00zzmodule_modulez00;
													{	/* BackEnd/c_main.scm 51 */
														obj_t BgL_arg1486z00_1900;

														BgL_arg1486z00_1900 =
															SYMBOL_TO_STRING(BgL_symbolz00_1899);
														BgL_arg1287z00_1657 =
															BGl_stringzd2copyzd2zz__r4_strings_6_7z00
															(BgL_arg1486z00_1900);
													}
												}
												BgL_arg1285z00_1656 =
													MAKE_YOUNG_PAIR(BgL_arg1287z00_1657, BNIL);
											}
											BgL_arg1284z00_1655 =
												MAKE_YOUNG_PAIR(BINT(0L), BgL_arg1285z00_1656);
										}
										BgL_arg1280z00_1652 =
											MAKE_YOUNG_PAIR(BgL_arg1282z00_1654, BgL_arg1284z00_1655);
									}
									{	/* BackEnd/c_main.scm 52 */
										obj_t BgL_arg1288z00_1658;
										obj_t BgL_arg1289z00_1659;

										{	/* BackEnd/c_main.scm 52 */
											obj_t BgL_arg1291z00_1660;

											{	/* BackEnd/c_main.scm 52 */
												obj_t BgL_arg1292z00_1661;

												{	/* BackEnd/c_main.scm 52 */
													obj_t BgL_arg1293z00_1662;

													BgL_arg1293z00_1662 =
														MAKE_YOUNG_PAIR(((obj_t) CNST_TABLE_REF(1)), BNIL);
													BgL_arg1292z00_1661 =
														MAKE_YOUNG_PAIR(
														((obj_t) CNST_TABLE_REF(2)), BgL_arg1293z00_1662);
												}
												BgL_arg1291z00_1660 =
													MAKE_YOUNG_PAIR(
													((obj_t) CNST_TABLE_REF(3)), BgL_arg1292z00_1661);
											}
											BgL_arg1288z00_1658 =
												MAKE_YOUNG_PAIR(BgL_arg1291z00_1660, BNIL);
										}
										{	/* BackEnd/c_main.scm 53 */
											obj_t BgL_arg1294z00_1663;
											obj_t BgL_arg1295z00_1664;

											{	/* BackEnd/c_main.scm 53 */
												obj_t BgL_arg1296z00_1665;

												{	/* BackEnd/c_main.scm 53 */
													obj_t BgL_arg1297z00_1666;
													obj_t BgL_arg1298z00_1667;

													{	/* BackEnd/c_main.scm 53 */
														obj_t BgL_arg1299z00_1668;

														{	/* BackEnd/c_main.scm 53 */
															obj_t BgL_arg1301z00_1669;

															{	/* BackEnd/c_main.scm 53 */
																obj_t BgL_arg1302z00_1670;

																{	/* BackEnd/c_main.scm 53 */
																	obj_t BgL_arg1303z00_1671;

																	BgL_arg1303z00_1671 =
																		MAKE_YOUNG_PAIR(BINT(0L), BNIL);
																	BgL_arg1302z00_1670 =
																		MAKE_YOUNG_PAIR(
																		((obj_t)
																			CNST_TABLE_REF(6)), BgL_arg1303z00_1671);
																}
																BgL_arg1301z00_1669 =
																	MAKE_YOUNG_PAIR(BgL_arg1302z00_1670, BNIL);
															}
															BgL_arg1299z00_1668 =
																MAKE_YOUNG_PAIR(
																((obj_t)
																	CNST_TABLE_REF(7)), BgL_arg1301z00_1669);
														}
														BgL_arg1297z00_1666 =
															MAKE_YOUNG_PAIR(BgL_arg1299z00_1668, BNIL);
													}
													{	/* BackEnd/c_main.scm 54 */
														obj_t BgL_arg1304z00_1672;

														{	/* BackEnd/c_main.scm 54 */
															obj_t BgL_arg1305z00_1673;

															BgL_arg1305z00_1673 =
																MAKE_YOUNG_PAIR(
																((obj_t) CNST_TABLE_REF(8)), BNIL);
															BgL_arg1304z00_1672 =
																MAKE_YOUNG_PAIR(
																((obj_t)
																	CNST_TABLE_REF(4)), BgL_arg1305z00_1673);
														}
														BgL_arg1298z00_1667 =
															MAKE_YOUNG_PAIR(BgL_arg1304z00_1672, BNIL);
													}
													BgL_arg1296z00_1665 =
														MAKE_YOUNG_PAIR(BgL_arg1297z00_1666,
														BgL_arg1298z00_1667);
												}
												BgL_arg1294z00_1663 =
													MAKE_YOUNG_PAIR(
													((obj_t) CNST_TABLE_REF(9)), BgL_arg1296z00_1665);
											}
											BgL_arg1295z00_1664 = MAKE_YOUNG_PAIR(BUNSPEC, BNIL);
											BgL_arg1289z00_1659 =
												MAKE_YOUNG_PAIR(BgL_arg1294z00_1663,
												BgL_arg1295z00_1664);
										}
										BgL_arg1281z00_1653 =
											MAKE_YOUNG_PAIR(BgL_arg1288z00_1658, BgL_arg1289z00_1659);
									}
									BgL_arg1279z00_1651 =
										MAKE_YOUNG_PAIR(BgL_arg1280z00_1652, BgL_arg1281z00_1653);
								}
								BgL_mainzd2bodyzd2_1625 =
									MAKE_YOUNG_PAIR(
									((obj_t) CNST_TABLE_REF(5)), BgL_arg1279z00_1651);
							}
					}
					{	/* BackEnd/c_main.scm 39 */
						BgL_nodez00_bglt BgL_nodez00_1626;

						{	/* BackEnd/c_main.scm 56 */
							BgL_nodez00_bglt BgL_nodez00_1628;

							BgL_nodez00_1628 =
								BGl_sexpzd2ze3nodez31zzast_sexpz00(BgL_mainzd2bodyzd2_1625,
								BgL_argsz00_1624, BFALSE, ((obj_t) CNST_TABLE_REF(10)));
							BGl_lvtypezd2nodez12zc0zzast_lvtypez00(BgL_nodez00_1628);
							BgL_nodez00_1626 = BgL_nodez00_1628;
						}
						{	/* BackEnd/c_main.scm 56 */
							BgL_globalz00_bglt BgL_bigloozd2mainzd2_1627;

							BgL_bigloozd2mainzd2_1627 =
								BGl_defzd2globalzd2sfunz12z12zzast_glozd2defzd2(
								((obj_t)
									CNST_TABLE_REF(11)),
								((obj_t)
									CNST_TABLE_REF(12)), BgL_argsz00_1624,
								BGl_za2moduleza2z00zzmodule_modulez00,
								((obj_t) CNST_TABLE_REF(13)), ((obj_t) CNST_TABLE_REF(14)),
								((obj_t) CNST_TABLE_REF(15)), ((obj_t) BgL_nodez00_1626));
							{	/* BackEnd/c_main.scm 59 */

								{	/* BackEnd/c_main.scm 67 */
									obj_t BgL_vz00_1902;

									BgL_vz00_1902 = ((obj_t) CNST_TABLE_REF(16));
									((((BgL_globalz00_bglt) COBJECT(BgL_bigloozd2mainzd2_1627))->
											BgL_importz00) = ((obj_t) BgL_vz00_1902), BUNSPEC);
								}
								((((BgL_variablez00_bglt) COBJECT(
												((BgL_variablez00_bglt) BgL_bigloozd2mainzd2_1627)))->
										BgL_namez00) =
									((obj_t) BGl_string1494z00zzbackend_c_mainz00), BUNSPEC);
								return ((obj_t) BgL_bigloozd2mainzd2_1627);
							}
						}
					}
				}
			}
		}

	}



/* &make-bigloo-main */
	obj_t BGl_z62makezd2bigloozd2mainz62zzbackend_c_mainz00(obj_t BgL_envz00_1938)
	{
		{	/* BackEnd/c_main.scm 37 */
			return BGl_makezd2bigloozd2mainz00zzbackend_c_mainz00();
		}

	}



/* object-init */
	obj_t BGl_objectzd2initzd2zzbackend_c_mainz00(void)
	{
		{	/* BackEnd/c_main.scm 15 */
			return BUNSPEC;
		}

	}



/* generic-init */
	obj_t BGl_genericzd2initzd2zzbackend_c_mainz00(void)
	{
		{	/* BackEnd/c_main.scm 15 */
			return BUNSPEC;
		}

	}



/* method-init */
	obj_t BGl_methodzd2initzd2zzbackend_c_mainz00(void)
	{
		{	/* BackEnd/c_main.scm 15 */
			return BUNSPEC;
		}

	}



/* imported-modules-init */
	obj_t BGl_importedzd2moduleszd2initz00zzbackend_c_mainz00(void)
	{
		{	/* BackEnd/c_main.scm 15 */
			BGl_modulezd2initializa7ationz75zzengine_paramz00(161876678L,
				BSTRING_TO_STRING(BGl_string1495z00zzbackend_c_mainz00));
			BGl_modulezd2initializa7ationz75zzmodule_modulez00(158397907L,
				BSTRING_TO_STRING(BGl_string1495z00zzbackend_c_mainz00));
			BGl_modulezd2initializa7ationz75zztype_typez00(515343395L,
				BSTRING_TO_STRING(BGl_string1495z00zzbackend_c_mainz00));
			BGl_modulezd2initializa7ationz75zztype_cachez00(489890788L,
				BSTRING_TO_STRING(BGl_string1495z00zzbackend_c_mainz00));
			BGl_modulezd2initializa7ationz75zzobject_classz00(502007119L,
				BSTRING_TO_STRING(BGl_string1495z00zzbackend_c_mainz00));
			BGl_modulezd2initializa7ationz75zzobject_slotsz00(151271251L,
				BSTRING_TO_STRING(BGl_string1495z00zzbackend_c_mainz00));
			BGl_modulezd2initializa7ationz75zzast_varz00(90839984L,
				BSTRING_TO_STRING(BGl_string1495z00zzbackend_c_mainz00));
			BGl_modulezd2initializa7ationz75zzast_nodez00(469732712L,
				BSTRING_TO_STRING(BGl_string1495z00zzbackend_c_mainz00));
			BGl_modulezd2initializa7ationz75zzast_envz00(146730773L,
				BSTRING_TO_STRING(BGl_string1495z00zzbackend_c_mainz00));
			BGl_modulezd2initializa7ationz75zzast_sexpz00(163122759L,
				BSTRING_TO_STRING(BGl_string1495z00zzbackend_c_mainz00));
			BGl_modulezd2initializa7ationz75zzast_localz00(315247917L,
				BSTRING_TO_STRING(BGl_string1495z00zzbackend_c_mainz00));
			BGl_modulezd2initializa7ationz75zzast_glozd2defzd2(44601789L,
				BSTRING_TO_STRING(BGl_string1495z00zzbackend_c_mainz00));
			BGl_modulezd2initializa7ationz75zzast_lvtypez00(189769752L,
				BSTRING_TO_STRING(BGl_string1495z00zzbackend_c_mainz00));
			BGl_modulezd2initializa7ationz75zztools_shapez00(365925558L,
				BSTRING_TO_STRING(BGl_string1495z00zzbackend_c_mainz00));
			BGl_modulezd2initializa7ationz75zzbackend_c_prototypez00(364917963L,
				BSTRING_TO_STRING(BGl_string1495z00zzbackend_c_mainz00));
			return
				BGl_modulezd2initializa7ationz75zzbackend_cplibz00(395792377L,
				BSTRING_TO_STRING(BGl_string1495z00zzbackend_c_mainz00));
		}

	}

#ifdef __cplusplus
}
#endif
